@@ -2,7 +2,7 @@
 #include <math.h>
 #include <string.h>
 #include "canvas_demo.h"
-#include "gnome-canvas-path-def.h"
+#include <libgnomecanvas/gnome-canvas-path-def.h>
 #include <gdk/gdkkeysyms.h>
 
 static void
@@ -733,8 +733,10 @@ key_press (GnomeCanvas *canvas, GdkEventKey *event, gpointer data)
 		gnome_canvas_scroll_to (canvas, x - 10, y);
 	else if (event->keyval == GDK_Right)
 		gnome_canvas_scroll_to (canvas, x + 10, y);
+	else
+		return FALSE;
 
-	return FALSE;
+	return TRUE;
 }
 
 GtkWidget *
@@ -785,6 +787,8 @@ create_canvas_primitives (gint aa)
 	setup_curves (root);
 	setup_widgets (root);
 
+/* FIXME: we should have a 'rotation' spinbutton too - and fix the acute
+   bugs with that ... */
 #if 0
 	{
 		double affine[6];
