@@ -35,9 +35,10 @@ gnome_canvas_points_get_type (void)
 
     if (!type_canvas_points)
 	type_canvas_points = g_boxed_type_register_static
-	    ("GnomeCanvasPoints", 
+	    ("GnomeCanvasPoints", NULL,
 	     (GBoxedCopyFunc) gnome_canvas_points_ref,
-	     (GBoxedFreeFunc) gnome_canvas_points_unref);
+	     (GBoxedFreeFunc) gnome_canvas_points_unref,
+	     TRUE);
 
     return type_canvas_points;
 }
